@@ -15,24 +15,15 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
  nForecasts <- ensembleSize(ensembleData)
  if (!all(M == 1:nForecasts)) ensembleData <- ensembleData[,M]
 
-# remove instances missing all forecasts, obs, or dates
+## remove instances missing all forecasts
 
  M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
  M <- M | is.na(ensembleVerifObs(ensembleData))
- M <- M | is.na(ensembleDates(ensembleData))
  ensembleData <- ensembleData[!M,]
  
- if (is.null(obs <- ensembleVerifObs(ensembleData)))
-   stop("verification observations required")
-
-#nObs <- length(obs)
- nObs <- ensembleNobs(ensembleData)
-
- if (!is.null(seed)) set.seed(seed)
-
 ## match specified dates with dateTable in fit
 
- dateTable <- names(fit$nIter)
+ dateTable <- dimnames(fit$weights)[[2]]
 
  if (!is.null(dates)) {
 
@@ -40,7 +31,7 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
 
    if (length(dates) > length(dateTable)) 
      stop("parameters not available for some dates")
- 
+
    K <- match( dates, dateTable, nomatch=0)
 
    if (any(!K) || !length(K)) 
@@ -54,29 +45,30 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
 
   }
 
- nObs <- length(obs)
+ ensDates <- ensembleDates(ensembleData)
 
 ## match dates in data with dateTable
- if (is.null(ensDates <- ensembleDates(ensembleData))) {
-
+ if (is.null(ensDates) || all(is.na(ensDates))) {
    if (length(dates) > 1) stop("date ambiguity")
+   nObs <- nrow(ensembleData)
    Dates <- rep( dates, nObs)
-
  }
  else {
-
+## remove instances missing dates
+   if (any(M <- is.na(ensDates))) {
+     ensembleData <- ensembleData[!M,]
+     ensDates <- ensembleDates(ensembleData)
+   }
    Dates <- as.character(ensDates)
-
-   L <- as.logical(match(Dates, dates, nomatch=0))
-
+   L <- as.logical(match( Dates, dates, nomatch=0))
    if (all(!L) || !length(L)) 
      stop("model fit dates incompatible with ensemble data")
    Dates <- Dates[L]
    ensembleData <- ensembleData[L,]
-   obs <- obs[L]
-   nObs <- length(obs)
+   nObs <- length(Dates)
  }
 
+ obs <- ensembleVerifObs(ensembleData)
  nForecasts <- ensembleSize(ensembleData) 
 
  CRPS <- crpsSim <- sampleMedian <- rep(NA, nObs)
